Package: shinyGovstyle
Title: Custom Gov Style Inputs for Shiny
Version: 0.2.0
Authors@R: c(
    person("Ross", "Wyatt", , "ross.wyatt@justice.gov.uk", role = "aut"),
    person("Cam", "Race", , "camrace8@gmail.com", role = c("aut", "cre")),
    person("Sarah", "Wong", role = "aut"),
    person("Richard", "Bielby", , "richard.bielby@education.gov.uk", role = "ctb"),
    person("Charlotte", "Foster", , "charlotte.foster@education.gov.uk", role = "ctb"),
    person("Jeni", "Martin", role = "ctb"),
    person("Andrew", "Baker", , "andrew.baker1@dhsc.gov.uk", role = "ctb")
  )
Description: Collection of 'shiny' application styling that are based on
    the GOV.UK Design System. See
    <https://design-system.service.gov.uk/components/> for details.
License: GPL (>= 3)
URL: https://github.com/dfe-analytical-services/shinyGovstyle
BugReports: https://github.com/dfe-analytical-services/shinyGovstyle/issues
Depends: R (>= 4.1.0)
Imports: htmltools, jsonlite, lifecycle, purrr, reactable, readODS,
        readr, shiny (>= 0.14), shinyjs, stringr, writexl
Suggests: bslib, knitr, rlang, rmarkdown, shinytest2, testthat
VignetteBuilder: knitr
Config/testthat/edition: 3
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-04-13 12:07:26 UTC; camra
Author: Ross Wyatt [aut],
  Cam Race [aut, cre],
  Sarah Wong [aut],
  Richard Bielby [ctb],
  Charlotte Foster [ctb],
  Jeni Martin [ctb],
  Andrew Baker [ctb]
Maintainer: Cam Race <camrace8@gmail.com>
Repository: CRAN
Date/Publication: 2026-04-13 12:40:02 UTC
Built: R 4.6.0; ; 2026-04-30 03:33:02 UTC; unix
