#' Case data
#'
#' Simple example dataset containing case management data, used to demonstrate
#' tabs in the example app.
#'
#' @format A data frame with 12 rows and 4 variables:
#' \describe{
#' \item{tabs}{The tab the data belongs to}
#' \item{case_manager}{The name of the case manager}
#' \item{cases_open}{Number of open cases}
#' \item{cases_closed}{Number of closed cases}
#' }
#' @source Random data generated for the shinyGovstyle package
"case_data"

#' Transport data
#'
#' Simple example dataset containing transport data, used to demonstrate
#' various table styles in the example app.
#'
#' @format A data frame with 10 rows and 5 variables:
#' \describe{
#' \item{months}{The month the data belongs to}
#' \item{colours}{The colour of the vehicle}
#' \item{bikes}{Cost of bikes}
#' \item{vans}{Cost of vans}
#' \item{buses}{Cost of buses}
#' }
#' @source Random data generated for the shinyGovstyle package
"transport_data"

#' Transport data small
#'
#' Smaller example dataset containing transport data, used to demonstrate
#' various table styles in the example app.
#'
#' @format A data frame with 3 rows and 3 variables:
#' \describe{
#' \item{months}{The month the data belongs to}
#' \item{bikes}{Cost of bikes}
#' \item{cars}{Cost of cars}
#' }
#' @source Random data generated for the shinyGovstyle package
"transport_data_small"
