# error_summary works

    Code
      error_summary
    Output
      <div id="error1" class="govuk-error-summary">
        <h2 class="govuk-error-summary__title">Error Title</h2>
        <div id="error1list" class="govuk-error-summary__body">
          <ul class="govuk-list govuk-error-summary__list">
            <li>error entry 1</li>
            <li>error entry 2</li>
          </ul>
        </div>
      </div>

