% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/accordion.R
\name{accordion}
\alias{accordion}
\title{Accordion Function}
\usage{
accordion(inputId, titles, descriptions)
}
\arguments{
\item{inputId}{Input Id for the accordion}

\item{titles}{Add the titles for the accordion}

\item{descriptions}{Add the main text for the accordion}
}
\value{
an accordion HTML shiny tag object
}
\description{
This function inserts a accordion
}
\examples{
ui <- shiny::fluidPage(
  shinyGovstyle::header(
    org_name = "Example",
    service_name = "User Examples",
    logo = "shinyGovstyle/images/moj_logo.png",
    logo_alt_text = "Ministry of Justice logo"
  ),
  shinyGovstyle::banner(
    inputId = "banner", type = "beta", 'This is a new service'
  ),
  shinyGovstyle::gov_layout(
    size = "two-thirds",
    accordion(
      "acc1",
      c(
        "Writing well for the web",
        "Writing well for specialists",
        "Know your audience",
        "How people read"
      ),
      c(
        "This is the content for Writing well for the web.",
        "This is the content for Writing well for specialists.",
        "This is the content for Know your audience.",
        "This is the content for How people read."
      )
    )
  ),
  shinyGovstyle::footer(full = TRUE)
)

server <- function(input, output, session) {}

if (interactive()) shiny::shinyApp(ui = ui, server = server)
}
\seealso{
Other Govstyle tables tabs and accordions: 
\code{\link{govReactable}()},
\code{\link{govReactable-shiny}},
\code{\link{govTable}()},
\code{\link{govTabs}()}
}
\concept{Govstyle tables tabs and accordions}
