% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/full_width_overrides.R
\name{full_width_overrides}
\alias{full_width_overrides}
\title{Styling overrides for to give full width}
\usage{
full_width_overrides()
}
\value{
HTML containing CSS styling overrides
}
\description{
\ifelse{html}{\href{https://lifecycle.r-lib.org/articles/stages.html#experimental}{\figure{lifecycle-experimental.svg}{options: alt='[Experimental]'}}}{\strong{[Experimental]}}
This is an experimental function that will likely be removed in future
releases, as we work through updating the core package styling and
adding full width options into the components themselves. This is not
well tested and may cause unexpected styling issues when combined with
components from other packages, use at your own risk.
}
\examples{
shinyGovstyle::full_width_overrides()
}
\seealso{
Other Govstyle styling: 
\code{\link{font}()}
}
\concept{Govstyle styling}
