% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/insert_text.R
\name{insert_text}
\alias{insert_text}
\title{Insert Text Function}
\usage{
insert_text(inputId, text)
}
\arguments{
\item{inputId}{The input slot that will be used to access the value}

\item{text}{Text that you want to display on the insert}
}
\value{
a insert text HTML shiny tag object
}
\description{
This function loads the insert text component to display additional
information in a special format.
}
\examples{
ui <- shiny::fluidPage(
  shinyGovstyle::header(
    org_name = "Example",
    service_name = "User Examples",
    logo="shinyGovstyle/images/moj_logo.png"
  ),
  shinyGovstyle::gov_layout(
    size = "two-thirds",
    shinyGovstyle::insert_text(
      inputId = "note",
      text = paste(
        "It can take up to 8 weeks to register a lasting power of",
        "attorney if there are no mistakes in the application."
      )
    )
  ),
  shinyGovstyle::footer(full = TRUE)
)

server <- function(input, output, session) {}
if (interactive()) shinyApp(ui = ui, server = server)
}
\seealso{
Other Govstyle feedback types: 
\code{\link{details}()},
\code{\link{gov_summary}()},
\code{\link{label_hint}()},
\code{\link{noti_banner}()},
\code{\link{panel_output}()},
\code{\link{tag_Input}()},
\code{\link{value_box}()},
\code{\link{warning_text}()}
}
\concept{Govstyle feedback types}
