% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/header.R
\name{header}
\alias{header}
\title{Header Function}
\usage{
header(
  org_name = "Shiny example app",
  service_name = NULL,
  logo = "shinyGovstyle/images/Dept_logo.svg",
  main_text = lifecycle::deprecated(),
  secondary_text = lifecycle::deprecated(),
  main_link = NULL,
  secondary_link = NULL,
  logo_alt_text = "Departmental logo",
  main_alt_text = NULL,
  secondary_alt_text = NULL,
  logo_width = 66,
  logo_height = 34
)
}
\arguments{
\item{org_name}{Organisation name that goes in the header}

\item{service_name}{Service name to supplement the organisation name}

\item{logo}{Add a link to a logo which will apply in the header. Use crown to
use the crown SVG version on GOV UK}

\item{main_text}{\ifelse{html}{\href{https://lifecycle.r-lib.org/articles/stages.html#deprecated}{\figure{lifecycle-deprecated.svg}{options: alt='[Deprecated]'}}}{\strong{[Deprecated]}} Use \code{org_name} instead}

\item{secondary_text}{\ifelse{html}{\href{https://lifecycle.r-lib.org/articles/stages.html#deprecated}{\figure{lifecycle-deprecated.svg}{options: alt='[Deprecated]'}}}{\strong{[Deprecated]}} Use \code{service_name}
instead}

\item{main_link}{Add a link for clicking on main text
\ifelse{html}{\href{https://lifecycle.r-lib.org/articles/stages.html#deprecated}{\figure{lifecycle-deprecated.svg}{options: alt='[Deprecated]'}}}{\strong{[Deprecated]}}}

\item{secondary_link}{Add a link for clicking on secondary
header \ifelse{html}{\href{https://lifecycle.r-lib.org/articles/stages.html#deprecated}{\figure{lifecycle-deprecated.svg}{options: alt='[Deprecated]'}}}{\strong{[Deprecated]}}}

\item{logo_alt_text}{Add alternative text for the logo. Should be used when a
logo is used}

\item{main_alt_text}{Add alternative text for the main link. Should be used
when a main link is used \ifelse{html}{\href{https://lifecycle.r-lib.org/articles/stages.html#deprecated}{\figure{lifecycle-deprecated.svg}{options: alt='[Deprecated]'}}}{\strong{[Deprecated]}}}

\item{secondary_alt_text}{Add alternative text for the secondary link. Should
be used when a secondary link is used \ifelse{html}{\href{https://lifecycle.r-lib.org/articles/stages.html#deprecated}{\figure{lifecycle-deprecated.svg}{options: alt='[Deprecated]'}}}{\strong{[Deprecated]}}}

\item{logo_width}{Change the logo size width CSS to improve fit}

\item{logo_height}{Change the logo size height CSS to improve fit}
}
\value{
a header HTML shiny tag object
}
\description{
This function create a header banner. For use at top of the screen
}
\examples{
ui <- shiny::fluidPage(
  shinyGovstyle::header(
    org_name = "Example",
    service_name = "User Examples",
    logo = "shinyGovstyle/images/moj_logo.png",
    logo_alt_text = "Ministry of Justice Logo"
  )
)

server <- function(input, output, session) {}

if (interactive()) shinyApp(ui = ui, server = server)
}
\seealso{
Other Govstyle page structure: 
\code{\link{banner}()},
\code{\link{cookieBanner}()},
\code{\link{footer}()},
\code{\link{gov_layout}()},
\code{\link{layouts}},
\code{\link{skip_to_main}()}
}
\concept{Govstyle page structure}
