% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data-examples.R
\docType{data}
\name{transport_data_small}
\alias{transport_data_small}
\title{Transport data small}
\format{
A data frame with 3 rows and 3 variables:
\describe{
\item{months}{The month the data belongs to}
\item{bikes}{Cost of bikes}
\item{cars}{Cost of cars}
}
}
\source{
Random data generated for the shinyGovstyle package
}
\usage{
transport_data_small
}
\description{
Smaller example dataset containing transport data, used to demonstrate
various table styles in the example app.
}
\keyword{datasets}
