% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/label_hint.R
\name{label_hint}
\alias{label_hint}
\title{Label with Hint Function}
\usage{
label_hint(inputId, label, hint_input = NULL)
}
\arguments{
\item{inputId}{The input slot that will be used to access the value}

\item{label}{Display label for the control, or \code{NULL} for no label}

\item{hint_input}{Display hint label for the control, or \code{NULL} for
no hint label}
}
\value{
a label hint HTML shiny tag object
}
\description{
This function inserts a label and optional hint.
}
\examples{
ui <- shiny::fluidPage(
  shinyGovstyle::header(
    org_name = "Example",
    service_name = "User Examples",
    logo="shinyGovstyle/images/moj_logo.png"
  ),
  shinyGovstyle::gov_layout(
    size = "two-thirds",
    label_hint(
      inputId = "label1",
      label = "This is a label",
      hint_input = "This is a hint"
    )
  ),
  shinyGovstyle::footer(full = TRUE)
)

server <- function(input, output, session) {}
if (interactive()) shinyApp(ui = ui, server = server)
}
\seealso{
Other Govstyle feedback types: 
\code{\link{details}()},
\code{\link{gov_summary}()},
\code{\link{insert_text}()},
\code{\link{noti_banner}()},
\code{\link{panel_output}()},
\code{\link{tag_Input}()},
\code{\link{value_box}()},
\code{\link{warning_text}()}
}
\concept{Govstyle feedback types}
