% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/footer.R
\name{footer_link}
\alias{footer_link}
\title{Create a footer link for use in \code{footer()} function}
\usage{
footer_link(link, link_name = NULL)
}
\arguments{
\item{link}{Character string containing either link text or url}

\item{link_name}{Name of a link where a URL has been provided in link_text}
}
\value{
HTML tag list item
}
\description{
Create a footer link for use in \code{footer()} function
}
\examples{
# Internal (i.e. within dashboard) link
shinyGovstyle:::footer_link("Cookie statement")
# Named internal link
shinyGovstyle:::footer_link("cookie_statement", "Cookies")
# External link
shinyGovstyle:::footer_link(
  "https://www.gov.uk/government/organisations/government-digital-service",
  "Government Digital Service"
)
}
\keyword{internal}
