% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/clean_heading_text.R
\name{clean_heading_text}
\alias{clean_heading_text}
\title{Clean heading text function
This internal function is used in \code{heading_text()}
to create an automated link between the two}
\usage{
clean_heading_text(text)
}
\arguments{
\item{text}{string}
}
\value{
a string
}
\description{
Clean heading text function
This internal function is used in \code{heading_text()}
to create an automated link between the two
}
\keyword{internal}
