% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/gov_layout.R
\name{gov_layout}
\alias{gov_layout}
\title{Page Layout Function}
\usage{
gov_layout(..., inputID = "main", size = "full")
}
\arguments{
\item{...}{include the components of the UI that you want within the
main page.}

\item{inputID}{ID of the main div. Defaults to "main"}

\item{size}{Layout of the page. Optional are full, one-half, two-thirds,
one-third and one-quarter. Defaults to "full"}
}
\value{
a HTML shiny layout div
}
\description{
This function loads the page layout, This doesn't work as well as
the \code{gov_main_layout} and associated functions. This is being kept for now
as a simpler version where grids are not needed.
}
\examples{
ui <- shiny::fluidPage(
  shinyGovstyle::header(
    org_name = "Example",
    service_name = "User Examples",
    logo="shinyGovstyle/images/moj_logo.png"
  ),
  shinyGovstyle::gov_layout(
    size = "full",
    shinyGovstyle::panel_output(
      inputId = "panel1",
      main_text = "Application Complete",
      sub_text = paste(
        "Thank you for submitting your application.",
        "Your reference is xvsiq"
      )
    ),
    shinyGovstyle::footer(full = TRUE)
  )
)

server <- function(input, output, session) {}
if (interactive()) shinyApp(ui = ui, server = server)
}
\seealso{
Other Govstyle page structure: 
\code{\link{banner}()},
\code{\link{cookieBanner}()},
\code{\link{footer}()},
\code{\link{header}()},
\code{\link{layouts}},
\code{\link{skip_to_main}()}
}
\concept{Govstyle page structure}
