% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/govTabs.R
\name{govTabs}
\alias{govTabs}
\title{Tabs Function}
\usage{
govTabs(inputId, df, group_col)
}
\arguments{
\item{inputId}{The Id to access the tag}

\item{df}{A single dataframe with all data. See example for structure}

\item{group_col}{The column name with the groups to be used as tabs}
}
\value{
a tab table HTML shiny tag object
}
\description{
This function creates a tabs based table. It requires a single dataframe
with a grouping variable.
}
\examples{
ui <- shiny::fluidPage(
  shinyGovstyle::header(
    org_name = "Example",
    service_name = "User Examples",
    logo = "shinyGovstyle/images/moj_logo.png",
    logo_alt_text = "Ministry of Justice logo"
  ),
  shinyGovstyle::gov_main_layout(
    size = "two-thirds",
    shinyGovstyle::govTabs("tabs", shinyGovstyle::case_data, "tabs")
  ),
  shinyGovstyle::footer(full = TRUE)
)

server <- function(input, output, session) {}
if (interactive()) shinyApp(ui = ui, server = server)
}
\seealso{
Other Govstyle tables tabs and accordions: 
\code{\link{accordion}()},
\code{\link{govReactable}()},
\code{\link{govReactable-shiny}},
\code{\link{govTable}()}
}
\concept{Govstyle tables tabs and accordions}
