% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data-examples.R
\docType{data}
\name{case_data}
\alias{case_data}
\title{Case data}
\format{
A data frame with 12 rows and 4 variables:
\describe{
\item{tabs}{The tab the data belongs to}
\item{case_manager}{The name of the case manager}
\item{cases_open}{Number of open cases}
\item{cases_closed}{Number of closed cases}
}
}
\source{
Random data generated for the shinyGovstyle package
}
\usage{
case_data
}
\description{
Simple example dataset containing case management data, used to demonstrate
tabs in the example app.
}
\keyword{datasets}
