% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/warning_text.R
\name{warning_text}
\alias{warning_text}
\title{Warning Text Function}
\usage{
warning_text(inputId, text)
}
\arguments{
\item{inputId}{The input slot that will be used to access the value}

\item{text}{Text that goes in the main}
}
\value{
a warning box HTML shiny tag object
}
\description{
This function create warning text.
}
\examples{
shinyGovstyle::warning_text(
  inputId = "warn1",
  text = "You can be fined up to £5,000 if you do not register."
)
}
\seealso{
Other Govstyle feedback types: 
\code{\link{details}()},
\code{\link{gov_summary}()},
\code{\link{insert_text}()},
\code{\link{label_hint}()},
\code{\link{noti_banner}()},
\code{\link{panel_output}()},
\code{\link{tag_Input}()},
\code{\link{value_box}()}
}
\concept{Govstyle feedback types}
