% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/button_Input.R
\name{button_Input}
\alias{button_Input}
\title{Button Function}
\usage{
button_Input(inputId, label, type = "default")
}
\arguments{
\item{inputId}{The input slot that will be used to access the value}

\item{label}{Display label for the control, or \code{NULL} for no label}

\item{type}{The type of button. Options are default, start, secondary and
warning. Defaults to "default"}
}
\value{
a HTML button shiny tag object
}
\description{
This function create a gov style button
}
\examples{
ui <- shiny::fluidPage(
  shinyGovstyle::header(
    org_name = "Example",
    service_name = "User Examples",
    logo = "shinyGovstyle/images/moj_logo.png"
  ),
  shinyGovstyle::gov_layout(
    size = "two-thirds",
    shinyGovstyle::button_Input(
      inputId = "btn1",
      label = "Continue",
      type = "default"
    )
  ),
  shinyGovstyle::footer(full = TRUE)
)

server <- function(input, output, session) {}

if (interactive()) shinyApp(ui = ui, server = server)
}
\seealso{
Other Govstyle select inputs: 
\code{\link{checkbox_Input}()},
\code{\link{file_Input}()},
\code{\link{radio_button_Input}()},
\code{\link{select_Input}()}
}
\concept{Govstyle select inputs}
