% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/noti_banner.R
\name{noti_banner}
\alias{noti_banner}
\title{Notification Banner Function}
\usage{
noti_banner(
  inputId,
  title_txt = "Important",
  body_txt = NULL,
  type = "standard"
)
}
\arguments{
\item{inputId}{The input Id for the banner}

\item{title_txt}{The wording that appears in the title}

\item{body_txt}{The wording that appears in the banner body}

\item{type}{The type of banner. Options are standard and success.
Standard is default}
}
\value{
a notification HTML shiny tag object
}
\description{
This function creates a notification banner.
}
\examples{
ui <- shiny::fluidPage(
  shinyGovstyle::header(
    org_name = "Example",
    service_name = "User Examples",
    logo="shinyGovstyle/images/moj_logo.png"
  ),
  shinyGovstyle::noti_banner(
    inputId = "banner", title_txt = "Important", body_txt = "Example text"
  )
)

server <- function(input, output, session) {}

if (interactive()) shinyApp(ui = ui, server = server)
}
\seealso{
Other Govstyle feedback types: 
\code{\link{details}()},
\code{\link{gov_summary}()},
\code{\link{insert_text}()},
\code{\link{label_hint}()},
\code{\link{panel_output}()},
\code{\link{tag_Input}()},
\code{\link{value_box}()},
\code{\link{warning_text}()}
}
\concept{Govstyle feedback types}
