% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tag.R
\name{tag_Input}
\alias{tag_Input}
\title{Tag Function}
\usage{
tag_Input(inputId, text, colour = "navy")
}
\arguments{
\item{inputId}{The Id to access the tag}

\item{text}{The text in the tag}

\item{colour}{The colour of the tag. Default is navy. Other options are
grey, green, teal, blue, purple, magenta, red, orange and yellow}
}
\value{
a tag HTML shiny tag object
}
\description{
This function creates a tag.
}
\examples{
ui <- shiny::fluidPage(
  shinyGovstyle::header(
    org_name = "Example",
    service_name = "User Examples",
    logo="shinyGovstyle/images/moj_logo.png"
  ),
  shinyGovstyle::gov_layout(
    size = "two-thirds",
    shinyGovstyle::tag_Input("tag1", "Complete"),
    shinyGovstyle::tag_Input("tag2", "Incomplete", "red")
  ),
  shinyGovstyle::footer(full = TRUE)
)

server <- function(input, output, session) {}
if (interactive()) shinyApp(ui = ui, server = server)
}
\seealso{
Other Govstyle feedback types: 
\code{\link{details}()},
\code{\link{gov_summary}()},
\code{\link{insert_text}()},
\code{\link{label_hint}()},
\code{\link{noti_banner}()},
\code{\link{panel_output}()},
\code{\link{value_box}()},
\code{\link{warning_text}()}
}
\concept{Govstyle feedback types}
