% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/banner.R
\name{banner}
\alias{banner}
\title{Banner Function}
\usage{
banner(inputId, type, label)
}
\arguments{
\item{inputId}{The input slot that will be used to access the value}

\item{type}{Main type of label e.g. alpha or beta. Can be any word}

\item{label}{text to display}
}
\value{
a banner HTML shiny tag object
}
\description{
This function create a detail component that you can click for further
details.
}
\examples{
ui <- shiny::fluidPage(
  shinyGovstyle::header(
    org_name = "Example",
    service_name = "User Examples",
    logo = "shinyGovstyle/images/moj_logo.png"
  ),
  shinyGovstyle::banner(
    inputId = "banner", type = "Beta", 'This is a new service'
  )
)

server <- function(input, output, session) {}

if (interactive()) shinyApp(ui = ui, server = server)
}
\seealso{
Other Govstyle page structure: 
\code{\link{cookieBanner}()},
\code{\link{footer}()},
\code{\link{gov_layout}()},
\code{\link{header}()},
\code{\link{layouts}},
\code{\link{skip_to_main}()}
}
\concept{Govstyle page structure}
