% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/heading_text.R
\name{heading_text}
\alias{heading_text}
\title{Heading Text Function}
\usage{
heading_text(text_input, size = "xl", id, level = 1)
}
\arguments{
\item{text_input}{Text to display}

\item{size}{Text size using xl, l, m, s. Defaults to xl}

\item{id}{Custom header id}

\item{level}{Heading level, integer between 1 and 6. Defaults to 1}
}
\value{
a heading text HTML shiny tag object
}
\description{
This function createS heading text
}
\examples{
shinyGovstyle::heading_text("This is great text")
shinyGovstyle::heading_text("This is great text", size = "l", level = 2)
}
\seealso{
Other Govstyle text types: 
\code{\link{date_Input}()},
\code{\link{gov_list}()},
\code{\link{input_field}()},
\code{\link{text_Input}()},
\code{\link{text_area_Input}()},
\code{\link{word_count}()}
}
\concept{Govstyle text types}
