% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/download_radios.R
\name{download_radios_handler}
\alias{download_radios_handler}
\title{Download with extension radios handler}
\usage{
download_radios_handler(id = "download_radios", file_name, file_contents)
}
\arguments{
\item{id}{Shiny element Id. Default is "download_radios", but must be
customised to be unique if multiple instances of this module are being
used in a single app. Must match up to the ID of a \code{download_radios()}
instance in UI code}

\item{file_name}{Name of the file to be downloaded}

\item{file_contents}{Contents to write to the download file}
}
\value{
Output for use with \code{download_radios()}
}
\description{
Download with extension radios handler
}
\examples{
ui <- shiny::fluidPage(
  download_radios("download_file",
    file_types = c("CSV", "ODS"),
    file_sizes = c("2 KB", "5 KB")
  )
)

server <- function(input, output, session) {
  output$download_file <- download_radios_handler(
    "download_file",
    file_name = "simple_data_frame",
    file_contents = mtcars
  )
}

if (interactive()) shinyApp(ui, server)
}
\seealso{
Other Govstyle actions: 
\code{\link{download_button}()},
\code{\link{download_link}()},
\code{\link{download_radios}()},
\code{\link{external_link}()}
}
\concept{Govstyle actions}
