% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/details.R
\name{details}
\alias{details}
\title{Details Function}
\usage{
details(inputId, label, help_text)
}
\arguments{
\item{inputId}{The input slot that will be used to access the value}

\item{label}{Main label text}

\item{help_text}{Additional help information in the component}
}
\value{
a details box HTML shiny tag object
}
\description{
This function create a detail component that you can click for further
details.
}
\examples{
ui <- shiny::fluidPage(
  shinyGovstyle::header(
    org_name = "Example",
    service_name = "User Examples",
    logo = "shinyGovstyle/images/moj_logo.png"
  ),
  shinyGovstyle::gov_layout(
    size = "two-thirds",
    shinyGovstyle::details(
      inputId = "help_div",
      label = "Help with form",
      help_text = "To complete the form you need to fill it in..."
    )
  ),
  shinyGovstyle::footer(full = TRUE)
)

server <- function(input, output, session) {}

if (interactive()) shinyApp(ui = ui, server = server)
}
\seealso{
Other Govstyle feedback types: 
\code{\link{gov_summary}()},
\code{\link{insert_text}()},
\code{\link{label_hint}()},
\code{\link{noti_banner}()},
\code{\link{panel_output}()},
\code{\link{tag_Input}()},
\code{\link{value_box}()},
\code{\link{warning_text}()}
}
\concept{Govstyle feedback types}
