% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/skip_to_main.R
\name{skip_to_main}
\alias{skip_to_main}
\title{Skip to main content link}
\usage{
skip_to_main(id = "main")
}
\arguments{
\item{id}{An optional parameter to specify the Id of the main content
section, will be automatically preceeded by a hash '#'. Default is
"main" to match the "#main" Id within \code{gov_main()}.}
}
\value{
A Shiny tag representing the 'Skip to main content' link
}
\description{
This function generates a 'Skip to main content' link, which is
typically used by keyboard users to bypass content and
navigate directly to the main content of a page.
}
\examples{
ui <- shiny::fluidPage(
  skip_to_main(),
  header(
    org_name = "Example",
    service_name = "User Examples",
    logo="shinyGovstyle/images/moj_logo.png"
  ),
  gov_main_layout(
    heading_text("Example heading"),
  )
)

server <- function(input, output, session){}

if (interactive()) shinyApp(ui = ui, server = server)
}
\seealso{
Other Govstyle page structure: 
\code{\link{banner}()},
\code{\link{cookieBanner}()},
\code{\link{footer}()},
\code{\link{gov_layout}()},
\code{\link{header}()},
\code{\link{layouts}}
}
\concept{Govstyle page structure}
