% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/select_input.R
\name{select_Input}
\alias{select_Input}
\title{Select Function}
\usage{
select_Input(inputId, label, select_text, select_value)
}
\arguments{
\item{inputId}{Input Id for the component}

\item{label}{Insert the text for the label}

\item{select_text}{Add the text that will apply in the drop down as a list}

\item{select_value}{Add the value that will be used for each selection}
}
\value{
a select input HTML shiny tag object
}
\description{
This function inserts a select box
}
\examples{
ui <- shiny::fluidPage(
  shinyGovstyle::header(
    org_name = "Example",
    service_name = "User Examples",
    logo = "shinyGovstyle/images/moj_logo.png",
    logo_alt_text = "Ministry of Justice logo"
  ),
  shinyGovstyle::gov_layout(
    size = "full",
    select_Input(
      inputId = "sorter",
      label = "Sort by",
      select_text = c(
        "Recently published",
        "Recently updated",
        "Most views",
        "Most comments"
      ),
      select_value = c("published", "updated", "view", "comments")
    ),
    shiny::tags$br()
  ),
  shinyGovstyle::footer(full = TRUE)
)

server <- function(input, output, session) {}
if (interactive()) shinyApp(ui = ui, server = server)
}
\seealso{
Other Govstyle select inputs: 
\code{\link{button_Input}()},
\code{\link{checkbox_Input}()},
\code{\link{file_Input}()},
\code{\link{radio_button_Input}()}
}
\concept{Govstyle select inputs}
