% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/run_example.R
\name{run_example}
\alias{run_example}
\title{Run examples}
\usage{
run_example()
}
\value{
runs an R Shiny app with examples in
}
\description{
This function runs an example R Shiny app showcasing different parts of the
package. Code for the app can be found in the inst/example_app folder in the
source code.
}
\details{
The app uses the \href{https://rstudio.github.io/bslib/}{bslib package} as is
generally recommended for Shiny apps.

The app is also deployed at the following URL:
https://department-for-education.shinyapps.io/shinygovstyle-example-app/
}
\examples{
if (interactive()) run_example()
}
