% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/value_box.R
\name{value_box}
\alias{value_box}
\title{Create a value text box with optional description and colour}
\usage{
value_box(value = "your value goes here", text = NA, colour = "blue")
}
\arguments{
\item{value}{Character. The primary value to display in the value box.
Defaults to "your value goes here"}

\item{text}{Character or NA. An optional description to appear below the
value. If not provided (default is NA), the description will not be
displayed}

\item{colour}{Character. A colour to apply to the value box. Defaults
to "blue". Choose from the following: "grey", "purple", "teal",
"blue", "yellow", "orange", "red", "magenta", or "green"}
}
\value{
A Shiny \code{div} tag representing the value box, styled according
to the specified parameters
}
\description{
This function generates a value text box with an optional description and
customisable colour.
}
\details{
The text box can be used in Shiny applications to display highlighted
information, such as statistics or key metrics.
}
\examples{
value_box(
  value = "1,000,000",
  text = "This is the latest value for the selected inputs.",
  colour = "purple"
)
}
\seealso{
Other Govstyle feedback types: 
\code{\link{details}()},
\code{\link{gov_summary}()},
\code{\link{insert_text}()},
\code{\link{label_hint}()},
\code{\link{noti_banner}()},
\code{\link{panel_output}()},
\code{\link{tag_Input}()},
\code{\link{warning_text}()}
}
\concept{Govstyle feedback types}
