% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/govTable.R
\name{govTable}
\alias{govTable}
\title{Table Function}
\usage{
govTable(
  inputId,
  df,
  caption,
  caption_size = "l",
  num_col = NULL,
  width_overwrite = NULL
)
}
\arguments{
\item{inputId}{Input Id for the table}

\item{df}{expects a dataframe to create a table}

\item{caption}{adds a caption to the table as a header}

\item{caption_size}{adjust the size of caption. Options are s, m, l, xl,
with l as the default}

\item{num_col}{adds numeric class format to these columns}

\item{width_overwrite}{change width. Need to include width for every column.
Columns must add up to 1.
Options are three-quarters, two-thirds, one-half, one-third, one-quarter.
Default is \code{NULL}}
}
\value{
a table HTML shiny tag object
}
\description{
This function inserts a gov styled table. Format is with header looking
rows and columns
}
\examples{
ui <- shiny::fluidPage(
  shinyGovstyle::gov_layout(
    size = "two-thirds",
    shinyGovstyle::govTable(
      "tab1",
      shinyGovstyle::transport_data_small,
      "Test",
      "l",
      num_col = c(2,3),
      width_overwrite = c("one-half", "one-quarter", "one-quarter")
    )
  )
)

server <- function(input, output, session) {}

if (interactive()) shinyApp(ui = ui, server = server)
}
\seealso{
Other Govstyle tables tabs and accordions: 
\code{\link{accordion}()},
\code{\link{govReactable}()},
\code{\link{govReactable-shiny}},
\code{\link{govTabs}()}
}
\concept{Govstyle tables tabs and accordions}
