% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/gov_list.R
\name{gov_list}
\alias{gov_list}
\title{Gov List function}
\usage{
gov_list(list, style = "none")
}
\arguments{
\item{list}{vector of list}

\item{style}{options: "none", "bullet", "number". defaults to "none"}
}
\description{
Gov List function
}
\examples{
ui <- shiny::fluidPage(
  shinyGovstyle::header(
    org_name = "Example",
    service_name = "User Examples"
  ),
  shinyGovstyle::banner(
    inputId = "banner", type = "beta", 'This is a new service'
  ),
  shinyGovstyle::gov_layout(
    size = "two-thirds",
    shinyGovstyle::heading_text("gov_list", size = "s"),
    shinyGovstyle::gov_text("List:"),
    gov_list(list = c("a", "b", "c")),
    shinyGovstyle::gov_text("Bulleted list:"),
    gov_list(list = c("a", "b", "c"), style = "bullet"),
    shinyGovstyle::gov_text("Numbered list:"),
    gov_list(list = c("one", "two", "three"), style = "number")
  )
)

server <- function(input, output, session) {}

if (interactive()) shinyApp(ui = ui, server = server)
}
\seealso{
Other Govstyle text types: 
\code{\link{date_Input}()},
\code{\link{heading_text}()},
\code{\link{input_field}()},
\code{\link{text_Input}()},
\code{\link{text_area_Input}()},
\code{\link{word_count}()}
}
\concept{Govstyle text types}
